@@ -152,7 +152,7 @@ def Translate(text, langCombo):
                 'lang': langCombo,
                 'text': text
                 },
-            timeout = 0.6
+            timeout = 0.5
         )
     except requests.Timeout:
         PrYellow('A request timed out!')
@@ -190,9 +190,13 @@ def RepoCheck():
     if sourceLang not in os.listdir():
         if sourceLang + '_' not in list(map(lambda x: x[:3], os.listdir())):
             PrRed('\nNo directory for source language files has been found!\nAdd or rename the directory with the ISO 639-1 code for its language')
+            re.purge
+            exit()
         else:
             if len(list(filter(lambda x: x == sourceLang + '_', map(lambda x: x[:3], os.listdir())))) > 1:
                 PrRed('\nThere are more than one directory named with source language code.\nPlease designate only one.')
+                re.purge
+                exit()
             else:
                 sourceDir = list(filter(lambda x: x[:3] == sourceLang + '_', os.listdir()))[0]
     else:
